import ApolloClient from 'apollo-client';
import { InMemoryCache } from 'apollo-cache-inmemory';
import { createHttpLink } from 'apollo-link-http';
import { setContext } from 'apollo-link-context';
import { ApolloLink } from 'apollo-link';
import fetch from 'isomorphic-fetch';
import SdkAuth, { TokenProvider } from '@commercetools/sdk-auth';
import { onError } from 'apollo-link-error';
import gql from 'graphql-tag';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __awaiter(thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}
function __makeTemplateObject(cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
}

var createAuthClient = function (config) {
    return new SdkAuth({
        host: config.authHost,
        projectKey: config.projectKey,
        disableRefreshToken: false,
        credentials: {
            clientId: config.clientId,
            clientSecret: config.clientSecret
        },
        scopes: config.scopes
    });
};
var getCurrentToken = function (options) {
    if (options === void 0) { options = {}; }
    if (currentToken) {
        return currentToken;
    }
    return options.currentToken;
};
var isTokenActive = function (sdkAuth, token) { return __awaiter(void 0, void 0, void 0, function () {
    var tokenIntrospection;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, sdkAuth.introspectToken(token.access_token)];
            case 1:
                tokenIntrospection = _a.sent();
                return [2 /*return*/, tokenIntrospection.active];
        }
    });
}); };
var getTokenFlow = function (sdkAuth, options) {
    if (options === void 0) { options = {}; }
    return __awaiter(void 0, void 0, void 0, function () {
        var currentToken, tokenActive;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    currentToken = getCurrentToken(options);
                    if (options.customerCredentials) {
                        return [2 /*return*/, sdkAuth.customerPasswordFlow(options.customerCredentials)];
                    }
                    if (!currentToken) return [3 /*break*/, 2];
                    return [4 /*yield*/, isTokenActive(sdkAuth, currentToken)];
                case 1:
                    tokenActive = _a.sent();
                    if (tokenActive) {
                        return [2 /*return*/, Promise.resolve(currentToken)];
                    }
                    _a.label = 2;
                case 2: return [2 /*return*/, sdkAuth.anonymousFlow()];
            }
        });
    });
};
var createAccessToken = function (options) {
    if (options === void 0) { options = {}; }
    return __awaiter(void 0, void 0, void 0, function () {
        var sdkAuth, tokenInfo, tokenProvider;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    sdkAuth = createAuthClient(api);
                    return [4 /*yield*/, getTokenFlow(sdkAuth, options)];
                case 1:
                    tokenInfo = _a.sent();
                    tokenProvider = new TokenProvider({ sdkAuth: sdkAuth }, tokenInfo);
                    return [2 /*return*/, tokenProvider.getTokenInfo()];
            }
        });
    });
};

var createCommerceToolsLink = function () {
    var httpLink = createHttpLink({ uri: api.uri, fetch: fetch });
    var authLink = setContext(function (_, _a) {
        var headers = _a.headers;
        return __awaiter(void 0, void 0, void 0, function () {
            var token;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0: return [4 /*yield*/, createAccessToken({ currentToken: currentToken })];
                    case 1:
                        token = _b.sent();
                        auth.onTokenChange(token);
                        return [2 /*return*/, {
                                headers: __assign(__assign({}, headers), { authorization: "Bearer " + token.access_token })
                            }];
                }
            });
        });
    });
    var onErrorLink = onError(function (_a) {
        var graphQLErrors = _a.graphQLErrors, networkError = _a.networkError;
        if (graphQLErrors) {
            graphQLErrors.map(function (_a) {
                var message = _a.message, locations = _a.locations, path = _a.path;
                var parsedLocations = locations.map(function (_a) {
                    var column = _a.column, line = _a.line;
                    return "[column: " + column + ", line: " + line + "]";
                });
                if (!message.includes('Resource Owner Password Credentials Grant')) {
                    console.error("[GraphQL error]: Message: " + message + ", Location: " + parsedLocations.join(', ') + ", Path: " + path);
                }
            });
        }
        if (networkError) {
            console.error("[Network error]: " + networkError);
        }
    });
    return ApolloLink.from([onErrorLink, authLink, httpLink]);
};

var ProductPriceFragment = "\n  fragment DefaultProductPrice on ProductPrice {\n    discounted {\n      value {\n        type\n        currencyCode\n        centAmount\n        fractionDigits\n      }\n      discount {\n        validFrom\n        validUntil\n        isActive\n        name(acceptLanguage: $acceptLanguage)\n      }\n    }\n    value {\n      type\n      currencyCode\n      centAmount\n      fractionDigits\n    }\n  }\n";
var AddressFragment = "\n  fragment DefaultAddress on Address {\n    title\n    firstName\n    lastName\n    streetName\n    streetNumber\n    postalCode\n    city\n    region\n    country\n    company\n    state\n    contactInfo {\n      phone\n      email\n    }\n  }\n";
var CustomerFragment = "\n  fragment DefaultCustomer on Customer {\n    version\n    firstName\n    lastName\n    email\n  }\n";
var LineItemFragment = "\n  " + ProductPriceFragment + "\n\n  fragment DefaultLineItem on LineItem {\n    id\n    productId\n    name(acceptLanguage: $acceptLanguage)\n    productSlug(acceptLanguage: $acceptLanguage)\n    quantity\n    discountedPricePerQuantity {\n      quantity\n      discountedPrice {\n        value {\n          centAmount\n        }\n        includedDiscounts {\n          discount {\n            name(acceptLanguage: $acceptLanguage)\n            isActive\n          }\n        }\n      }\n    }\n    variant {\n      id\n      sku\n      price(currency: \"USD\") {\n        tiers {\n          value {\n            centAmount\n          }\n        }\n        value {\n          centAmount\n        }\n        discounted {\n          value {\n            centAmount\n          }\n          discount {\n            isActive\n            name(acceptLanguage: $acceptLanguage)\n          }\n        }\n      }\n      images {\n        url\n        label\n      }\n      attributeList {\n        name\n        ... on BooleanAttribute {\n          booleanValue: value\n        }\n        ... on DateAttribute {\n          dateValue: value\n        }\n        ... on DateTimeAttribute {\n          dateTimeValue: value\n        }\n        ... on StringAttribute {\n          stringValue: value\n        }\n        ... on TimeAttribute {\n          timeValue: value\n        }\n        ... on NumberAttribute {\n          numberValue: value\n        }\n        ... on EnumAttribute {\n          key\n          label\n        }\n        ... on LocalizedEnumAttribute {\n          key\n          localizedLabel: label(locale: $locale)\n        }\n        ... on LocalizedStringAttribute {\n          localizedString: value(locale: $locale)\n        }\n        ... on MoneyAttribute {\n          centAmount\n          currencyCode\n        }\n        ... on ReferenceAttribute {\n          typeId\n          id\n        }\n      }\n    }\n    price {\n      ...DefaultProductPrice\n    }\n  }\n";
var ShippingMethodFragment = "\n  fragment DefaultShippingMethod on ShippingMethod {\n    id\n    version\n    name\n    description\n    isDefault\n    localizedDescription(acceptLanguage: $acceptLanguage)\n    zoneRates {\n      zone {\n        id\n        name\n      }\n      shippingRates {\n        freeAbove\n        isMatching\n        price {\n          centAmount\n        }\n      }\n    }\n  }\n";
var CartFragment = "\n  " + AddressFragment + "\n  " + CustomerFragment + "\n  " + LineItemFragment + "\n  " + ShippingMethodFragment + "\n\n  fragment DefaultCart on Cart {\n    id\n    customerId\n    customerEmail\n    lineItems {\n      ...DefaultLineItem\n    }\n    totalPrice {\n      centAmount\n    }\n    shippingAddress {\n      ...DefaultAddress\n    }\n    billingAddress {\n      ...DefaultAddress\n    }\n    customer {\n      ...DefaultCustomer\n    }\n    totalPrice {\n      centAmount\n    }\n    taxedPrice {\n      totalNet {\n        centAmount\n      }\n      totalGross {\n        centAmount\n      }\n    }\n    paymentInfo {\n      payments {\n        id\n      }\n    }\n    shippingInfo {\n      price {\n        centAmount\n      }\n      shippingMethod {\n        ...DefaultShippingMethod\n      }\n    }\n    discountCodes {\n      discountCode {\n        id\n        code\n        isActive\n        validFrom\n        validUntil\n        name(acceptLanguage: $acceptLanguage)\n      }\n    }\n    refusedGifts {\n      isActive\n      validFrom\n      validUntil\n      name(acceptLanguage: $acceptLanguage)\n    }\n    cartState\n    version\n  }\n";
var OrderFragment = "\n  " + AddressFragment + "\n  " + LineItemFragment + "\n\n  fragment DefaultOrder on Order {\n    lineItems {\n      ...DefaultLineItem\n    }\n    totalPrice {\n      centAmount\n    }\n    orderState\n    id\n    orderNumber\n    version\n    createdAt\n    customerEmail\n    shipmentState\n    paymentState\n    shippingAddress {\n      ...DefaultAddress\n    }\n    billingAddress {\n      ...DefaultAddress\n    }\n  }\n";

var defaultQuery = gql(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  ", "\n\n  fragment Images on ProductVariant {\n    images {\n      url\n      label\n    }\n  }\n\n  fragment Price on ProductVariant {\n    price(currency: $currency, country: $country) {\n      ...DefaultProductPrice\n    }\n  }\n\n  fragment Attributes on ProductVariant {\n    attributeList {\n      name\n      ... on BooleanAttribute {\n        booleanValue: value\n      }\n      ... on DateAttribute {\n        dateValue: value\n      }\n      ... on DateTimeAttribute {\n        dateTimeValue: value\n      }\n      ... on StringAttribute {\n        stringValue: value\n      }\n      ... on TimeAttribute {\n        timeValue: value\n      }\n      ... on NumberAttribute {\n        numberValue: value\n      }\n      ... on EnumAttribute {\n        key\n        label\n      }\n      ... on LocalizedEnumAttribute {\n        key\n        localizedLabel: label(locale: $locale)\n      }\n      ... on LocalizedStringAttribute {\n        localizedString: value(locale: $locale)\n      }\n      ... on MoneyAttribute {\n        centAmount\n        currencyCode\n      }\n      ... on ReferenceAttribute {\n        typeId\n        id\n      }\n    }\n  }\n\n  fragment DefaultVariant on ProductVariant {\n    id\n    sku\n    ...Images\n    ...Price\n    ...Attributes\n  }\n\n  query products(\n    $where: String\n    $sort: [String!]\n    $limit: Int\n    $offset: Int\n    $skus: [String!]\n    $locale: Locale!\n    $acceptLanguage: [Locale!]\n    $currency: Currency!\n    $country: Country!\n  ) {\n    products(\n      where: $where\n      sort: $sort\n      limit: $limit\n      offset: $offset\n      skus: $skus\n    ) {\n      offset\n      count\n      total\n      results {\n        id\n        masterData {\n          current {\n            slug(acceptLanguage: $acceptLanguage)\n            name(acceptLanguage: $acceptLanguage)\n            metaTitle(acceptLanguage: $acceptLanguage)\n            metaKeywords(acceptLanguage: $acceptLanguage)\n            metaDescription(acceptLanguage: $acceptLanguage)\n            description(acceptLanguage: $acceptLanguage)\n            categoriesRef {\n              id\n            }\n            allVariants {\n              ...DefaultVariant\n            }\n            masterVariant {\n              ...DefaultVariant\n            }\n          }\n        }\n      }\n    }\n  }\n"], ["\n  ", "\n\n  fragment Images on ProductVariant {\n    images {\n      url\n      label\n    }\n  }\n\n  fragment Price on ProductVariant {\n    price(currency: $currency, country: $country) {\n      ...DefaultProductPrice\n    }\n  }\n\n  fragment Attributes on ProductVariant {\n    attributeList {\n      name\n      ... on BooleanAttribute {\n        booleanValue: value\n      }\n      ... on DateAttribute {\n        dateValue: value\n      }\n      ... on DateTimeAttribute {\n        dateTimeValue: value\n      }\n      ... on StringAttribute {\n        stringValue: value\n      }\n      ... on TimeAttribute {\n        timeValue: value\n      }\n      ... on NumberAttribute {\n        numberValue: value\n      }\n      ... on EnumAttribute {\n        key\n        label\n      }\n      ... on LocalizedEnumAttribute {\n        key\n        localizedLabel: label(locale: $locale)\n      }\n      ... on LocalizedStringAttribute {\n        localizedString: value(locale: $locale)\n      }\n      ... on MoneyAttribute {\n        centAmount\n        currencyCode\n      }\n      ... on ReferenceAttribute {\n        typeId\n        id\n      }\n    }\n  }\n\n  fragment DefaultVariant on ProductVariant {\n    id\n    sku\n    ...Images\n    ...Price\n    ...Attributes\n  }\n\n  query products(\n    $where: String\n    $sort: [String!]\n    $limit: Int\n    $offset: Int\n    $skus: [String!]\n    $locale: Locale!\n    $acceptLanguage: [Locale!]\n    $currency: Currency!\n    $country: Country!\n  ) {\n    products(\n      where: $where\n      sort: $sort\n      limit: $limit\n      offset: $offset\n      skus: $skus\n    ) {\n      offset\n      count\n      total\n      results {\n        id\n        masterData {\n          current {\n            slug(acceptLanguage: $acceptLanguage)\n            name(acceptLanguage: $acceptLanguage)\n            metaTitle(acceptLanguage: $acceptLanguage)\n            metaKeywords(acceptLanguage: $acceptLanguage)\n            metaDescription(acceptLanguage: $acceptLanguage)\n            description(acceptLanguage: $acceptLanguage)\n            categoriesRef {\n              id\n            }\n            allVariants {\n              ...DefaultVariant\n            }\n            masterVariant {\n              ...DefaultVariant\n            }\n          }\n        }\n      }\n    }\n  }\n"])), ProductPriceFragment);
var templateObject_1;

var AttributeType;
(function (AttributeType) {
    AttributeType["STRING"] = "StringAttribute";
    AttributeType["DATE"] = "DateAttribute";
    AttributeType["DATETIME"] = "DateTimeAttribute";
    AttributeType["TIME"] = "TimeAttribute";
    AttributeType["NUMBER"] = "NumberAttribute";
    AttributeType["ENUM"] = "EnumAttribute";
    AttributeType["LOCALIZED_ENUM"] = "LocalizedEnumAttribute";
    AttributeType["LOCALIZED_STRING"] = "LocalizedStringAttribute";
    AttributeType["MONEY"] = "MoneyAttribute";
    AttributeType["BOOLEAN"] = "BooleanAttribute";
})(AttributeType || (AttributeType = {}));

var buildAttributePredicate = function (attrName, attrType) { return function (option) {
    if (!option.selected) {
        return '';
    }
    var valuePredicate;
    switch (attrType) {
        case AttributeType.STRING:
            valuePredicate = "value = \"" + option.value + "\"";
            break;
        case AttributeType.DATE:
        case AttributeType.DATETIME:
        case AttributeType.TIME:
            valuePredicate = Array.isArray(option.value) ? "value >= \"" + option.value[0] + "\" and value <= \"" + option.value[1] + "\"" : "value = \"" + option.value + "\"";
            break;
        case AttributeType.NUMBER:
            valuePredicate = Array.isArray(option.value) ? "value >= " + option.value[0] + " and value <= " + option.value[1] : "value = " + option.value;
            break;
        case AttributeType.ENUM:
        case AttributeType.LOCALIZED_ENUM:
            valuePredicate = "value(key = \"" + option.value + "\")";
            break;
        case AttributeType.LOCALIZED_STRING:
            valuePredicate = "value(" + locale.toLowerCase() + " = \"" + option.value + "\")";
            break;
        case AttributeType.MONEY:
            valuePredicate = Array.isArray(option.value)
                ? "value(centAmount >= " + option.value[0] * 100 + " and centAmount <= " + option.value[1] * 100 + " and currencyCode = \"" + currency + "\")"
                : "value(centAmount = " + option.value + " and currencyCode = \"" + currency + "\")";
            break;
        case AttributeType.BOOLEAN:
            valuePredicate = "value = " + option.value;
            break;
    }
    return "masterData(current(masterVariant(attributes(name = \"" + attrName + "\" and " + valuePredicate + "))))";
}; };
var mapFilterToPredicates = function (_a) {
    var name = _a[0], filter = _a[1];
    var hasAnyOptionSelected = filter.options.some(function (option) { return option.selected; });
    if (!hasAnyOptionSelected) {
        return '';
    }
    var predicateMapper = buildAttributePredicate(name, filter.type);
    var predicates = filter.options.map(predicateMapper).filter(Boolean);
    return "(" + predicates.join(' or ') + ")";
};
var buildProductWhere = function (search) {
    var predicates = [];
    if (search === null || search === void 0 ? void 0 : search.catId) {
        var catIds = (Array.isArray(search.catId) ? search.catId : [search.catId]).join('","');
        predicates.push("masterData(current(categories(id in (\"" + catIds + "\"))))");
    }
    if (search === null || search === void 0 ? void 0 : search.slug) {
        var predicate = acceptLanguage.map(function (locale) { return locale + "=\"" + search.slug + "\""; }).join(' or ');
        predicates.push("masterData(current(slug(" + predicate + ")))");
    }
    if (search === null || search === void 0 ? void 0 : search.id) {
        predicates.push("id=\"" + search.id + "\"");
    }
    if (search === null || search === void 0 ? void 0 : search.filters) {
        predicates = __spreadArrays(predicates, Object.entries(search.filters).map(mapFilterToPredicates).filter(Boolean));
    }
    return predicates.join(' and ');
};
var buildCategoryWhere = function (search) {
    if (search === null || search === void 0 ? void 0 : search.catId) {
        return "id=\"" + search.catId + "\"";
    }
    if (search === null || search === void 0 ? void 0 : search.slug) {
        var predicate = acceptLanguage.map(function (locale) { return locale + "=\"" + search.slug + "\""; }).join(' or ');
        return "slug(" + predicate + ")";
    }
    return '';
};
var buildOrderWhere = function (search) {
    if (search === null || search === void 0 ? void 0 : search.id) {
        return "id=\"" + search.id + "\"";
    }
    return null;
};

var getProduct = function (search) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, query, variables;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                if (!search.customQuery) return [3 /*break*/, 2];
                _a = search.customQuery, query = _a.query, variables = _a.variables;
                return [4 /*yield*/, apolloClient.query({
                        query: gql(templateObject_1$1 || (templateObject_1$1 = __makeTemplateObject(["", ""], ["", ""])), query),
                        variables: variables
                    })];
            case 1: return [2 /*return*/, _b.sent()];
            case 2: return [4 /*yield*/, apolloClient.query({
                    query: defaultQuery,
                    variables: {
                        where: buildProductWhere(search),
                        skus: search.skus,
                        limit: search.limit,
                        offset: search.offset,
                        locale: locale,
                        acceptLanguage: acceptLanguage,
                        currency: currency,
                        country: country
                    },
                    // temporary, seems like bug in apollo:
                    // @link: https://github.com/apollographql/apollo-client/issues/3234
                    fetchPolicy: 'no-cache'
                })];
            case 3: return [2 /*return*/, _b.sent()];
        }
    });
}); };
var templateObject_1$1;

var defaultQuery$1 = gql(templateObject_1$2 || (templateObject_1$2 = __makeTemplateObject(["\n  fragment Children on Category {\n    id\n    slug(acceptLanguage: $acceptLanguage)\n    name(acceptLanguage: $acceptLanguage)\n    childCount\n  }\n\n  fragment DefaultCategory on Category {\n    id\n    slug(acceptLanguage: $acceptLanguage)\n    name(acceptLanguage: $acceptLanguage)\n    childCount\n    children {\n      ...Children\n      children {\n        ...Children\n        children {\n          ...Children\n        }\n      }\n    }\n  }\n\n  query categories($where: String, $sort: [String!], $limit: Int, $offset: Int, $acceptLanguage: [Locale!]) {\n    categories(where: $where, sort: $sort, limit: $limit, offset: $offset) {\n      offset\n      count\n      total\n      results {\n        id\n        slug(acceptLanguage: $acceptLanguage)\n        name(acceptLanguage: $acceptLanguage)\n        description(acceptLanguage: $acceptLanguage)\n        childCount\n        parent {\n          ...DefaultCategory\n          parent {\n            ...DefaultCategory\n            parent {\n              ...DefaultCategory\n            }\n          }\n        }\n        children {\n          ...DefaultCategory\n        }\n      }\n    }\n  }\n"], ["\n  fragment Children on Category {\n    id\n    slug(acceptLanguage: $acceptLanguage)\n    name(acceptLanguage: $acceptLanguage)\n    childCount\n  }\n\n  fragment DefaultCategory on Category {\n    id\n    slug(acceptLanguage: $acceptLanguage)\n    name(acceptLanguage: $acceptLanguage)\n    childCount\n    children {\n      ...Children\n      children {\n        ...Children\n        children {\n          ...Children\n        }\n      }\n    }\n  }\n\n  query categories($where: String, $sort: [String!], $limit: Int, $offset: Int, $acceptLanguage: [Locale!]) {\n    categories(where: $where, sort: $sort, limit: $limit, offset: $offset) {\n      offset\n      count\n      total\n      results {\n        id\n        slug(acceptLanguage: $acceptLanguage)\n        name(acceptLanguage: $acceptLanguage)\n        description(acceptLanguage: $acceptLanguage)\n        childCount\n        parent {\n          ...DefaultCategory\n          parent {\n            ...DefaultCategory\n            parent {\n              ...DefaultCategory\n            }\n          }\n        }\n        children {\n          ...DefaultCategory\n        }\n      }\n    }\n  }\n"])));
var templateObject_1$2;

var getCategory = function (search) { return __awaiter(void 0, void 0, void 0, function () {
    var _a, query, variables;
    return __generator(this, function (_b) {
        switch (_b.label) {
            case 0:
                if (!!search) return [3 /*break*/, 2];
                return [4 /*yield*/, apolloClient.query({
                        query: defaultQuery$1,
                        variables: { acceptLanguage: acceptLanguage }
                    })];
            case 1: return [2 /*return*/, _b.sent()];
            case 2:
                if (!search.customQuery) return [3 /*break*/, 4];
                _a = search.customQuery, query = _a.query, variables = _a.variables;
                return [4 /*yield*/, apolloClient.query({
                        query: gql(templateObject_1$3 || (templateObject_1$3 = __makeTemplateObject(["", ""], ["", ""])), query),
                        variables: variables
                    })];
            case 3: return [2 /*return*/, _b.sent()];
            case 4: return [4 /*yield*/, apolloClient.query({
                    query: defaultQuery$1,
                    variables: {
                        where: buildCategoryWhere(search),
                        limit: search.limit,
                        offset: search.offset,
                        acceptLanguage: acceptLanguage
                    }
                })];
            case 5: return [2 /*return*/, _b.sent()];
        }
    });
}); };
var templateObject_1$3;

var CreateCartMutation = gql(templateObject_1$4 || (templateObject_1$4 = __makeTemplateObject(["\n  ", "\n\n  mutation createCart($draft: MyCartDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $storeKey: KeyReferenceInput) {\n    cart: createMyCart(draft: $draft, storeKey: $storeKey) {\n      ...DefaultCart\n    }\n  }\n"], ["\n  ", "\n\n  mutation createCart($draft: MyCartDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $storeKey: KeyReferenceInput) {\n    cart: createMyCart(draft: $draft, storeKey: $storeKey) {\n      ...DefaultCart\n    }\n  }\n"])), CartFragment);
var templateObject_1$4;

var createCart = function (cartDraft) {
    if (cartDraft === void 0) { cartDraft = {}; }
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, apolloClient.mutate({
                        mutation: CreateCartMutation,
                        variables: {
                            acceptLanguage: acceptLanguage,
                            locale: locale,
                            draft: __assign({ currency: currency }, cartDraft)
                        }
                    })];
                case 1: return [2 /*return*/, _a.sent()];
            }
        });
    });
};

var CreateCartMutation$1 = gql(templateObject_1$5 || (templateObject_1$5 = __makeTemplateObject(["\n  ", "\n\n  mutation updateCart($id: String!, $version: Long!, $actions: [MyCartUpdateAction!]!, $locale: Locale!, $acceptLanguage: [Locale!]) {\n    cart: updateMyCart(id: $id, version: $version, actions: $actions) {\n      ...DefaultCart\n    }\n  }\n"], ["\n  ", "\n\n  mutation updateCart($id: String!, $version: Long!, $actions: [MyCartUpdateAction!]!, $locale: Locale!, $acceptLanguage: [Locale!]) {\n    cart: updateMyCart(id: $id, version: $version, actions: $actions) {\n      ...DefaultCart\n    }\n  }\n"])), CartFragment);
var templateObject_1$5;

var updateCart = function (cartData) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, apolloClient.mutate({
                    mutation: CreateCartMutation$1,
                    variables: __assign({ locale: locale,
                        acceptLanguage: acceptLanguage }, cartData),
                    fetchPolicy: 'no-cache'
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var defaultQuery$2 = gql(templateObject_1$6 || (templateObject_1$6 = __makeTemplateObject(["\n  ", "\n\n  query getCart($cartId: String!, $locale: Locale!, $acceptLanguage: [Locale!]) {\n    cart(id: $cartId) {\n      ...DefaultCart\n    }\n  }\n"], ["\n  ", "\n\n  query getCart($cartId: String!, $locale: Locale!, $acceptLanguage: [Locale!]) {\n    cart(id: $cartId) {\n      ...DefaultCart\n    }\n  }\n"])), CartFragment);
var templateObject_1$6;

var getCart = function (cartId) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, apolloClient.query({
                    query: defaultQuery$2,
                    variables: { cartId: cartId,
                        locale: locale,
                        acceptLanguage: acceptLanguage },
                    fetchPolicy: 'no-cache'
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var createAddLineItemAction = function (variant, quantity) { return ({
    addLineItem: {
        variantId: variant.id,
        quantity: quantity,
        sku: variant.sku
    }
}); };
var createRemoveLineItemAction = function (product) { return ({
    removeLineItem: {
        lineItemId: product.id,
        quantity: product.quantity
    }
}); };
var createChangeLineItemQuantityAction = function (product) { return ({
    changeLineItemQuantity: {
        lineItemId: product.id,
        quantity: product.quantity
    }
}); };
var setShippingAddressAction = function (shippingDetails) {
    var _a, _b, _c, _d;
    return ({
        setShippingAddress: {
            address: {
                title: shippingDetails.title,
                salutation: shippingDetails.salutation,
                firstName: shippingDetails.firstName,
                lastName: shippingDetails.lastName,
                streetName: shippingDetails.streetName,
                streetNumber: shippingDetails.streetNumber,
                additionalStreetInfo: shippingDetails.additionalStreetInfo,
                postalCode: shippingDetails.postalCode,
                city: shippingDetails.city,
                region: shippingDetails.region,
                state: shippingDetails.state,
                country: shippingDetails.country,
                company: shippingDetails.company,
                department: shippingDetails.department,
                building: shippingDetails.building,
                apartment: shippingDetails.apartment,
                pOBox: shippingDetails.pOBox,
                phone: (_a = shippingDetails.contactInfo) === null || _a === void 0 ? void 0 : _a.phone,
                mobile: (_b = shippingDetails.contactInfo) === null || _b === void 0 ? void 0 : _b.mobile,
                email: (_c = shippingDetails.contactInfo) === null || _c === void 0 ? void 0 : _c.email,
                fax: (_d = shippingDetails.contactInfo) === null || _d === void 0 ? void 0 : _d.fax,
                additionalAddressInfo: shippingDetails.additionalAddressInfo
            }
        }
    });
};
var setShippingMethodAction = function (shippingMethodId) { return ({
    setShippingMethod: {
        shippingMethod: shippingMethodId ? { id: shippingMethodId } : null
    }
}); };
var addPayment = function (payment) { return ({
    addPayment: { payment: payment }
}); };
var setBillingAddressAction = function (billingDetails) {
    var _a, _b, _c, _d;
    return ({
        setBillingAddress: {
            address: {
                title: billingDetails.title,
                salutation: billingDetails.salutation,
                firstName: billingDetails.firstName,
                lastName: billingDetails.lastName,
                streetName: billingDetails.streetName,
                streetNumber: billingDetails.streetNumber,
                additionalStreetInfo: billingDetails.additionalStreetInfo,
                postalCode: billingDetails.postalCode,
                city: billingDetails.city,
                region: billingDetails.region,
                state: billingDetails.state,
                country: billingDetails.country,
                company: billingDetails.company,
                department: billingDetails.department,
                building: billingDetails.building,
                apartment: billingDetails.apartment,
                pOBox: billingDetails.pOBox,
                phone: (_a = billingDetails.contactInfo) === null || _a === void 0 ? void 0 : _a.phone,
                mobile: (_b = billingDetails.contactInfo) === null || _b === void 0 ? void 0 : _b.mobile,
                email: (_c = billingDetails.contactInfo) === null || _c === void 0 ? void 0 : _c.email,
                fax: (_d = billingDetails.contactInfo) === null || _d === void 0 ? void 0 : _d.fax,
                additionalAddressInfo: billingDetails.additionalAddressInfo
            }
        }
    });
};
var addPaymentAction = function (paymentMethodId) { return ({
    addPayment: {
        payment: {
            id: paymentMethodId
        }
    }
}); };
var addDiscountCodeAction = function (code) { return ({
    addDiscountCode: { code: code }
}); };
var removeDiscountCodeAction = function (discountCode) { return ({
    removeDiscountCode: { discountCode: discountCode }
}); };
var setCustomerEmail = function (email) { return ({
    setCustomerEmail: { email: email }
}); };

var actions = /*#__PURE__*/Object.freeze({
    __proto__: null,
    createAddLineItemAction: createAddLineItemAction,
    createRemoveLineItemAction: createRemoveLineItemAction,
    createChangeLineItemQuantityAction: createChangeLineItemQuantityAction,
    setShippingAddressAction: setShippingAddressAction,
    setShippingMethodAction: setShippingMethodAction,
    addPayment: addPayment,
    setBillingAddressAction: setBillingAddressAction,
    addPaymentAction: addPaymentAction,
    addDiscountCodeAction: addDiscountCodeAction,
    removeDiscountCodeAction: removeDiscountCodeAction,
    setCustomerEmail: setCustomerEmail
});

var addToCart = function (cart, product, quantity) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, updateCart({
                    id: cart.id,
                    version: cart.version,
                    actions: [createAddLineItemAction(product, quantity)]
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var removeFromCart = function (cart, product) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, updateCart({
                    id: cart.id,
                    version: cart.version,
                    actions: [createRemoveLineItemAction(product)]
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var updateCartQuantity = function (cart, product) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, updateCart({
                    id: cart.id,
                    version: cart.version,
                    actions: [createChangeLineItemQuantityAction(product)]
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var basicProfile = gql(templateObject_1$7 || (templateObject_1$7 = __makeTemplateObject(["\n  ", "\n\n  query getMe($locale: Locale!, $acceptLanguage: [Locale!]) {\n    me {\n      activeCart {\n        ...DefaultCart\n      }\n    }\n  }\n"], ["\n  ", "\n\n  query getMe($locale: Locale!, $acceptLanguage: [Locale!]) {\n    me {\n      activeCart {\n        ...DefaultCart\n      }\n    }\n  }\n"])), CartFragment);
var fullProfile = gql(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  ", "\n  ", "\n\n  query getMe($locale: Locale!, $acceptLanguage: [Locale!]) {\n    me {\n      activeCart {\n        ...DefaultCart\n      }\n      customer {\n        ...DefaultCustomer\n      }\n    }\n  }\n"], ["\n  ", "\n  ", "\n\n  query getMe($locale: Locale!, $acceptLanguage: [Locale!]) {\n    me {\n      activeCart {\n        ...DefaultCart\n      }\n      customer {\n        ...DefaultCustomer\n      }\n    }\n  }\n"])), CartFragment, CustomerFragment);
var templateObject_1$7, templateObject_2;

var getMe = function (options) {
    if (options === void 0) { options = {}; }
    return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, apolloClient.query({
                        query: options.customer ? fullProfile : basicProfile,
                        variables: { locale: locale, acceptLanguage: acceptLanguage },
                        fetchPolicy: 'no-cache'
                    })];
                case 1: return [2 /*return*/, _a.sent()];
            }
        });
    });
};

var CreateMyOrderFromCartMutation = gql(templateObject_1$8 || (templateObject_1$8 = __makeTemplateObject(["\n  ", "\n\n  mutation createMyOrderFromCart($draft: OrderMyCartCommand!, $locale: Locale!, $acceptLanguage: [Locale!], $storeKey: KeyReferenceInput) {\n    order: createMyOrderFromCart(draft: $draft, storeKey: $storeKey) {\n      ...DefaultOrder\n    }\n  }\n"], ["\n  ", "\n\n  mutation createMyOrderFromCart($draft: OrderMyCartCommand!, $locale: Locale!, $acceptLanguage: [Locale!], $storeKey: KeyReferenceInput) {\n    order: createMyOrderFromCart(draft: $draft, storeKey: $storeKey) {\n      ...DefaultOrder\n    }\n  }\n"])), OrderFragment);
var templateObject_1$8;

var createMyOrderFromCart = function (draft) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, apolloClient.mutate({
                    mutation: CreateMyOrderFromCartMutation,
                    variables: { locale: locale,
                        acceptLanguage: acceptLanguage,
                        draft: draft },
                    fetchPolicy: 'no-cache'
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var defaultQuery$3 = gql(templateObject_1$9 || (templateObject_1$9 = __makeTemplateObject(["\n  ", "\n\n  query shippingMethods($acceptLanguage: [Locale!], $cartId: String!) {\n    shippingMethods: shippingMethodsByCart(id: $cartId) {\n      ...DefaultShippingMethod\n    }\n  }\n"], ["\n  ", "\n\n  query shippingMethods($acceptLanguage: [Locale!], $cartId: String!) {\n    shippingMethods: shippingMethodsByCart(id: $cartId) {\n      ...DefaultShippingMethod\n    }\n  }\n"])), ShippingMethodFragment);
var templateObject_1$9;

var getShippingMethods = function (cartId) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, apolloClient.query({
                    query: defaultQuery$3,
                    variables: { acceptLanguage: acceptLanguage, cartId: cartId },
                    fetchPolicy: 'no-cache'
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var updateShippingDetails = function (cart, shippingDetails) { return __awaiter(void 0, void 0, void 0, function () {
    var cartResponse;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, updateCart({
                    id: cart.id,
                    version: cart.version,
                    actions: [setShippingAddressAction(shippingDetails)]
                })];
            case 1:
                cartResponse = _a.sent();
                return [2 /*return*/, cartResponse];
        }
    });
}); };

var CustomerSignMeUpMutation = gql(templateObject_1$a || (templateObject_1$a = __makeTemplateObject(["\n  ", "\n  ", "\n\n  mutation customerSignMeUp($draft: CustomerSignMeUpDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $storeKey: KeyReferenceInput) {\n    user: customerSignMeUp(draft: $draft, storeKey: $storeKey) {\n      customer {\n        ...DefaultCustomer\n      }\n      cart {\n        ...DefaultCart\n      }\n    }\n  }\n"], ["\n  ", "\n  ", "\n\n  mutation customerSignMeUp($draft: CustomerSignMeUpDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $storeKey: KeyReferenceInput) {\n    user: customerSignMeUp(draft: $draft, storeKey: $storeKey) {\n      customer {\n        ...DefaultCustomer\n      }\n      cart {\n        ...DefaultCart\n      }\n    }\n  }\n"])), CustomerFragment, CartFragment);
var templateObject_1$a;

var customerSignMeUp = function (draft) { return __awaiter(void 0, void 0, void 0, function () {
    var registerResponse, customerCredentials, token;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, apolloClient.mutate({
                    mutation: CustomerSignMeUpMutation,
                    variables: { draft: draft, locale: locale, acceptLanguage: acceptLanguage },
                    fetchPolicy: 'no-cache'
                })];
            case 1:
                registerResponse = _a.sent();
                customerCredentials = { username: draft.email, password: draft.password };
                return [4 /*yield*/, createAccessToken({ currentToken: currentToken, customerCredentials: customerCredentials })];
            case 2:
                token = _a.sent();
                auth.onTokenChange(token);
                return [2 /*return*/, registerResponse];
        }
    });
}); };

var CustomerSignMeInMutation = gql(templateObject_1$b || (templateObject_1$b = __makeTemplateObject(["\n  ", "\n  ", "\n\n  mutation customerSignMeIn($draft: CustomerSignMeInDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $storeKey: KeyReferenceInput) {\n    user: customerSignMeIn(draft: $draft, storeKey: $storeKey) {\n      customer {\n        ...DefaultCustomer\n      }\n      cart {\n        ...DefaultCart\n      }\n    }\n  }\n"], ["\n  ", "\n  ", "\n\n  mutation customerSignMeIn($draft: CustomerSignMeInDraft!, $locale: Locale!, $acceptLanguage: [Locale!], $storeKey: KeyReferenceInput) {\n    user: customerSignMeIn(draft: $draft, storeKey: $storeKey) {\n      customer {\n        ...DefaultCustomer\n      }\n      cart {\n        ...DefaultCart\n      }\n    }\n  }\n"])), CustomerFragment, CartFragment);
var templateObject_1$b;

var customerSignMeIn = function (draft) { return __awaiter(void 0, void 0, void 0, function () {
    var loginResponse, customerCredentials, token;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, apolloClient.mutate({
                    mutation: CustomerSignMeInMutation,
                    variables: { draft: draft, locale: locale, acceptLanguage: acceptLanguage },
                    fetchPolicy: 'no-cache'
                })];
            case 1:
                loginResponse = _a.sent();
                customerCredentials = { username: draft.email, password: draft.password };
                return [4 /*yield*/, createAccessToken({ currentToken: currentToken, customerCredentials: customerCredentials })];
            case 2:
                token = _a.sent();
                auth.onTokenChange(token);
                return [2 /*return*/, loginResponse];
        }
    });
}); };

var customerSignOut = function () { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        auth.onTokenRemove();
        return [2 /*return*/];
    });
}); };

var defaultQuery$4 = gql(templateObject_1$c || (templateObject_1$c = __makeTemplateObject(["\n  ", "\n\n  query getMe($where: String, $sort: [String!], $limit: Int, $offset: Int, $locale: Locale!, $acceptLanguage: [Locale!]) {\n    me {\n      orders(where: $where, sort: $sort, limit: $limit, offset: $offset) {\n        results {\n          ...DefaultOrder\n        }\n      }\n    }\n  }\n"], ["\n  ", "\n\n  query getMe($where: String, $sort: [String!], $limit: Int, $offset: Int, $locale: Locale!, $acceptLanguage: [Locale!]) {\n    me {\n      orders(where: $where, sort: $sort, limit: $limit, offset: $offset) {\n        results {\n          ...DefaultOrder\n        }\n      }\n    }\n  }\n"])), OrderFragment);
var templateObject_1$c;

var index = (function (search) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, apolloClient.query({
                    query: defaultQuery$4,
                    variables: {
                        where: buildOrderWhere(search),
                        sort: search.sort,
                        limit: search.limit,
                        offset: search.offset,
                        acceptLanguage: acceptLanguage,
                        locale: locale
                    },
                    fetchPolicy: 'no-cache'
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); });

var applyCartCoupon = function (cart, discountCode) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, updateCart({
                    id: cart.id,
                    version: cart.version,
                    actions: [addDiscountCodeAction(discountCode)]
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var removeCartCoupon = function (cart, discountCode) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, updateCart({
                    id: cart.id,
                    version: cart.version,
                    actions: [removeDiscountCodeAction(discountCode)]
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var CustomerChangeMyPassword = gql(templateObject_1$d || (templateObject_1$d = __makeTemplateObject(["\n  ", "\n\n  mutation customerChangeMyPassword($version: Long!, $currentPassword: String!, $newPassword: String!, $storeKey: KeyReferenceInput) {\n    user: customerChangeMyPassword(version: $version, currentPassword: $currentPassword, newPassword: $newPassword, storeKey: $storeKey) {\n      ...DefaultCustomer\n    }\n  }\n"], ["\n  ", "\n\n  mutation customerChangeMyPassword($version: Long!, $currentPassword: String!, $newPassword: String!, $storeKey: KeyReferenceInput) {\n    user: customerChangeMyPassword(version: $version, currentPassword: $currentPassword, newPassword: $newPassword, storeKey: $storeKey) {\n      ...DefaultCustomer\n    }\n  }\n"])), CustomerFragment);
var templateObject_1$d;

var customerChangeMyPassword = function (version, currentPassword, newPassword) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, apolloClient.mutate({
                    mutation: CustomerChangeMyPassword,
                    variables: {
                        version: version,
                        currentPassword: currentPassword,
                        newPassword: newPassword
                    },
                    fetchPolicy: 'no-cache'
                })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    });
}); };

var apolloClient = null;
var locale = 'en';
var currency = '';
var country = '';
var countries = [];
var currencies = [];
var locales = [];
var acceptLanguage = ['en'];
var currentToken = null;
var api = null;
var auth = {
    onTokenChange: function () { },
    onTokenRemove: function () { }
};
var cookies = {
    currencyCookieName: 'vsf-currency',
    countryCookieName: 'vsf-country',
    localeCookieName: 'vsf-locale'
};
var languageMap = {};
var setup = function (setupConfig) {
    api = setupConfig.api || api;
    locale = setupConfig.locale || locale;
    currency = setupConfig.currency || currency;
    country = setupConfig.country || country;
    countries = setupConfig.countries || countries;
    currencies = setupConfig.currencies || currencies;
    locales = setupConfig.locales || locales;
    cookies = setupConfig.cookies || cookies;
    auth = setupConfig.auth || auth;
    currentToken = setupConfig.forceToken ? setupConfig.currentToken : setupConfig.currentToken || currentToken;
    languageMap = setupConfig.languageMap || languageMap;
    acceptLanguage = languageMap[locale] || setupConfig.acceptLanguage || acceptLanguage;
    if (setupConfig.api) {
        apolloClient = new ApolloClient(__assign({ link: createCommerceToolsLink(), cache: new InMemoryCache() }, setupConfig.customOptions));
    }
    return apolloClient;
};

export { acceptLanguage, addToCart, api, apolloClient, applyCartCoupon, auth, actions as cartActions, cookies, countries, country, createAccessToken, createCart, createMyOrderFromCart, currencies, currency, currentToken, customerChangeMyPassword, customerSignMeIn, customerSignMeUp, customerSignOut, getCart, getCategory, getMe, index as getMyOrders, getProduct, getShippingMethods, locale, locales, removeCartCoupon, removeFromCart, setup, updateCart, updateCartQuantity, updateShippingDetails };
//# sourceMappingURL=index.es.js.map
